*   Title:  SMALL CHARGED SPHERE:
*           denominators comparison to Schoonschip
*    File:  denoms-ck.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  July 9, 2012
* Revised:  July 9,10,28, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  RdotU from rdotu.sav
*  Output:  none
*
* This program loads the output denoms.sav of denoms.frm and
* checks it against Schoonschip results pasted from denoms.out.

*** DECLARATIONS

off statistics;

S eps;
S c;
S snorm;
I mu,nu;
V u,a,j,n;
T d1y,d2y,d3y,d1u,d2u,d1a;
Load denoms.sav;

S norm, aDa, p;
I Naa, Nab;

*** MODULES

* NeXT Schoonschip output, May 12 1993
* D1..., D2..., D3... replaced by d1..., d2..., d3... 28-Jul-12

L denom2 =
 + eps^-2
  * ( c^-2*norm^-2 )
 
 + d1y(Naa,n)*d1y(u,n)*d1u(Naa,n)*eps^-1
  * ( - 2*c^-4*norm^-4 )
 
 + d1y(Naa,n)*d2y(Naa,n,n)*eps^-1
  * ( c^-2*norm^-4 )
 
 + d1y(u,n)*d1y(u,n)*d1y(a,n)*eps^-1
  * ( c^-6*norm^-4 )
 
 + d1y(u,n)*d2y(u,n,n)*eps^-1
  * ( - c^-4*norm^-4 )
 
 + d1y(a,n)*eps^-1
  * ( - c^-4*norm^-2 ) + 0;

L denom3 = 
 + eps^-3
  * ( c^-3*norm^-3 )
 
 + eps^-1
  * ( 3/8*c^-7*norm^-1*aDa )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d1y(u,n)*d1u(Naa,n)*d1u(Nab,n)*eps^-1
  * ( 15/2*c^-7*norm^-7 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d2y(Naa,n,n)*d1u(Nab,n)*eps^-1
  * ( - 15/4*c^-5*norm^-7 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d2y(Nab,n,n)*d1u(Naa,n)*eps^-1
  * ( - 15/4*c^-5*norm^-7 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Naa,n,n)*d2y(Nab,n,n)*eps^-1
  * ( 15/8*c^-3*norm^-7 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Naa,n,n)*d1u(Nab,n)*eps^-1
  * ( - 3/4*c^-4*norm^-6 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Nab,n,n)*d1u(Naa,n)*eps^-1
  * ( 3/4*c^-4*norm^-6 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1u(Naa,n)*d1u(Nab,n)*eps^-1
  * ( - 3/2*c^-5*norm^-5 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d1u(Naa,n)*eps^-1
  * ( - 15/2*c^-9*norm^-7 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d2y(Naa,n,n)*eps^-1
  * ( 15/4*c^-7*norm^-7 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d2y(u,n,n)*d1u(Naa,n)*eps^-1
  * ( 15/2*c^-7*norm^-7 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1a(Naa,n)*eps^-1
  * ( 3/2*c^-7*norm^-5 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(a,n)*d1u(Naa,n)*eps^-1
  * ( 15/2*c^-7*norm^-5 )
 
 + d1y(Naa,n)*d1y(u,n)*d2y(Naa,n,n)*d2y(u,n,n)*eps^-1
  * ( - 15/4*c^-5*norm^-7 )
 
 + d1y(Naa,n)*d1y(u,n)*d1u(Naa,n)*eps^-2
  * ( - 3*c^-5*norm^-5 )
 
 + d1y(Naa,n)*d1y(u,n)*d2u(Naa,n,n)*eps^-1
  * ( - 3/2*c^-5*norm^-5 )
 
 + d1y(Naa,n)*d1y(a,n)*d2y(Naa,n,n)*eps^-1
  * ( - 9/4*c^-5*norm^-5 )
 
 + d1y(Naa,n)*d2y(Naa,n,n)*eps^-2
  * ( 3/2*c^-3*norm^-5 )
 
 + d1y(Naa,n)*d2y(u,n,n)*d1u(Naa,n)*eps^-1
  * ( - 3/2*c^-5*norm^-5 )
 
 + d1y(Naa,n)*d3y(Naa,n,n,n)*eps^-1
  * ( 1/2*c^-3*norm^-5 )
 
 + d1y(Naa,n)*d1a(Naa,n)*eps^-1
  * ( - 3/2*c^-5*norm^-3 )
 
 + d1y(u,n)*eps^-1
  * ( c^-8*norm^-2*aDa )
 
 + d1y(u,n)*d1y(u,n)*eps^-1
  * ( 3/4*c^-9*norm^-3*aDa )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)*eps^-1
  * ( - 1/8*c^-11*norm^-5*aDa )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d1y(a,n)*eps^-1
  * ( 15/8*c^-11*norm^-7 )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d2y(u,n,n)*eps^-1
  * ( - 15/4*c^-9*norm^-7 )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(j,n)*eps^-1
  * ( - 1/2*c^-9*norm^-5 )
 
 + d1y(u,n)*d1y(u,n)*d1y(a,n)*eps^-2
  * ( 3/2*c^-7*norm^-5 )
 
 + d1y(u,n)*d1y(u,n)*d1y(a,n)*d1y(a,n)*eps^-1
  * ( - 15/4*c^-9*norm^-5 )
 
 + d1y(u,n)*d1y(u,n)*d2y(u,n,n)*d2y(u,n,n)*eps^-1
  * ( 15/8*c^-7*norm^-7 )
 
 + d1y(u,n)*d1y(u,n)*d2y(a,n,n)*eps^-1
  * ( 3/4*c^-7*norm^-5 )
 
 + d1y(u,n)*d1y(a,n)*d2y(u,n,n)*eps^-1
  * ( 15/4*c^-7*norm^-5 )
 
 + d1y(u,n)*d1y(j,n)*eps^-1
  * ( 3/2*c^-7*norm^-3 )
 
 + d1y(u,n)*d2y(Naa,n,n)*d1u(Naa,n)*eps^-1
  * ( - 3/2*c^-5*norm^-5 )
 
 + d1y(u,n)*d2y(u,n,n)*eps^-2
  * ( - 3/2*c^-5*norm^-5 )
 
 + d1y(u,n)*d3y(u,n,n,n)*eps^-1
  * ( - 1/2*c^-5*norm^-5 )
 
 + d1y(a,n)*eps^-2
  * ( - 3/2*c^-5*norm^-3 )
 
 + d1y(a,n)*d1y(a,n)*eps^-1
  * ( 15/8*c^-7*norm^-3 )
 
 + d1y(j,n)*eps^-1
  * ( c^-6*norm^-2 )
 
 + d2y(Naa,n,n)*d2y(Naa,n,n)*eps^-1
  * ( 3/8*c^-3*norm^-5 )
 
 + d2y(u,n,n)*d2y(u,n,n)*eps^-1
  * ( - 3/8*c^-5*norm^-5 )
 
 + d2y(a,n,n)*eps^-1
  * ( - 3/4*c^-5*norm^-3 ) + 0;

id aDa = a.a;
id norm = snorm;
id norm^p? = snorm^p;
sum Naa,Nab;
.sort

hide denom2,denom3;

G diff1 = [1/RdotU^2] - denom2;
G diff2 = [1/RdotU^3] - denom3;
b eps,snorm;
print;
.end
