*   Title:  SMALL CHARGED SPHERE:
*           Lorentz force, retarded/advanced time interval
*           comparison to Schoonschip
*    File:  dtau-ck.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  July 6, 2012
* Revised:  July 6-10, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  TAU1, TAU2, TAU3 from dtau.sav
*  Output:  none
*
* This program loads the output dtau.sav of dtau.frm and checks
* it against Schoonschip results pasted from dtau.out.

*** DECLARATIONS

off statistics;

S eps, dtau;

S c,tau1,tau2,tau3;
S snorm;
I mu,nu;
V y,u,a,j,n;
T d1y,d2y,d3y,d1u,d2u,d1a;

Load dtau.sav;

S norm,p;
S aDa;
I Naa, Nab;

***MODULES

* NeXT Schoonschip output, October 24, 1990
* D1..., D2..., D3... replaced by d1..., d2..., d3... 28-Jul-12

L tau1o =  - c^-1*norm
 
 + d1y(u,n)
  * ( - c^-2 ) + 0;

L tau2o = 
 + d1y(Naa,n)*d1y(u,n)*d1u(Naa,n)
  * ( - c^-3*norm^-1 )
 
 + d1y(Naa,n)*d2y(Naa,n,n)
  * ( 1/2*c^-1*norm^-1 )
 
 + d1y(Naa,n)*d1u(Naa,n)
  * ( - c^-2 )
 
 + d1y(u,n)*d1y(u,n)*d1y(a,n)
  * ( 1/2*c^-5*norm^-1 )
 
 + d1y(u,n)*d1y(a,n)
  * ( c^-4 )
 
 + d1y(u,n)*d2y(u,n,n)
  * ( - 1/2*c^-3*norm^-1 )
 
 + d1y(a,n)
  * ( 1/2*c^-3*norm )
 
 + d2y(u,n,n)
  * ( - 1/2*c^-2 ) + 0;

L tau3o = 
  - 1/24*c^-5*norm^3*aDa
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d1y(u,n)*d1u(Naa,n)*d1u(Nab,n)
  * ( 1/2*c^-5*norm^-3 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d2y(Naa,n,n)*d1u(Nab,n)
  * ( - 1/4*c^-3*norm^-3 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1y(u,n)*d2y(Nab,n,n)*d1u(Naa,n)
  * ( - 1/4*c^-3*norm^-3 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Naa,n,n)*d2y(Nab,n,n)
  * ( 1/8*c^-1*norm^-3 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Naa,n,n)*d1u(Nab,n)
  * ( - 1/4*c^-2*norm^-2 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d2y(Nab,n,n)*d1u(Naa,n)
  * ( 1/4*c^-2*norm^-2 )
 
 + d1y(Naa,n)*d1y(Nab,n)*d1u(Naa,n)*d1u(Nab,n)
  * ( - 1/2*c^-3*norm^-1 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d1u(Naa,n)
  * ( - 1/2*c^-7*norm^-3 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d2y(Naa,n,n)
  * ( 1/4*c^-5*norm^-3 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d2y(u,n,n)*d1u(Naa,n)
  * ( 1/2*c^-5*norm^-3 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(u,n)*d1a(Naa,n)
  * ( 1/2*c^-5*norm^-1 )
 
 + d1y(Naa,n)*d1y(u,n)*d1y(a,n)*d1u(Naa,n)
  * ( 3/2*c^-5*norm^-1 )
 
 + d1y(Naa,n)*d1y(u,n)*d2y(Naa,n,n)*d2y(u,n,n)
  * ( - 1/4*c^-3*norm^-3 )
 
 + d1y(Naa,n)*d1y(u,n)*d2u(Naa,n,n)
  * ( - 1/2*c^-3*norm^-1 )
 
 + d1y(Naa,n)*d1y(u,n)*d1a(Naa,n)
  * ( c^-4 )
 
 + d1y(Naa,n)*d1y(a,n)*d2y(Naa,n,n)
  * ( - 1/4*c^-3*norm^-1 )
 
 + d1y(Naa,n)*d1y(a,n)*d1u(Naa,n)
  * ( c^-4 )
 
 + d1y(Naa,n)*d2y(u,n,n)*d1u(Naa,n)
  * ( - 1/2*c^-3*norm^-1 )
 
 + d1y(Naa,n)*d3y(Naa,n,n,n)
  * ( 1/6*c^-1*norm^-1 )
 
 + d1y(Naa,n)*d2u(Naa,n,n)
  * ( - 1/2*c^-2 )
 
 + d1y(Naa,n)*d1a(Naa,n)
  * ( 1/2*c^-3*norm )
 
 + d1y(u,n)
  * ( - 1/6*c^-6*norm^2*aDa )
 
 + d1y(u,n)*d1y(u,n)
  * ( - 1/4*c^-7*norm*aDa )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)
  * ( - 1/6*c^-8*aDa )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)
  * ( - 1/24*c^-9*norm^-1*aDa )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d1y(a,n)
  * ( 1/8*c^-9*norm^-3 )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(a,n)*d2y(u,n,n)
  * ( - 1/4*c^-7*norm^-3 )
 
 + d1y(u,n)*d1y(u,n)*d1y(u,n)*d1y(j,n)
  * ( - 1/6*c^-7*norm^-1 )
 
 + d1y(u,n)*d1y(u,n)*d1y(a,n)*d1y(a,n)
  * ( - 3/4*c^-7*norm^-1 )
 
 + d1y(u,n)*d1y(u,n)*d1y(j,n)
  * ( - 1/2*c^-6 )
 
 + d1y(u,n)*d1y(u,n)*d2y(u,n,n)*d2y(u,n,n)
  * ( 1/8*c^-5*norm^-3 )
 
 + d1y(u,n)*d1y(u,n)*d2y(a,n,n)
  * ( 1/4*c^-5*norm^-1 )
 
 + d1y(u,n)*d1y(a,n)*d1y(a,n)
  * ( - c^-6 )
 
 + d1y(u,n)*d1y(a,n)*d2y(u,n,n)
  * ( 3/4*c^-5*norm^-1 )
 
 + d1y(u,n)*d1y(j,n)
  * ( - 1/2*c^-5*norm )
 
 + d1y(u,n)*d2y(Naa,n,n)*d1u(Naa,n)
  * ( - 1/2*c^-3*norm^-1 )
 
 + d1y(u,n)*d2y(a,n,n)
  * ( 1/2*c^-4 )
 
 + d1y(u,n)*d3y(u,n,n,n)
  * ( - 1/6*c^-3*norm^-1 )
 
 + d1y(a,n)*d1y(a,n)
  * ( - 3/8*c^-5*norm )
 
 + d1y(a,n)*d2y(u,n,n)
  * ( 1/2*c^-4 )
 
 + d1y(j,n)
  * ( - 1/6*c^-4*norm^2 )
 
 + d2y(Naa,n,n)*d2y(Naa,n,n)
  * ( 1/8*c^-1*norm^-1 )
 
 + d2y(Naa,n,n)*d1u(Naa,n)
  * ( - 1/2*c^-2 )
 
 + d2y(u,n,n)*d2y(u,n,n)
  * ( - 1/8*c^-3*norm^-1 )
 
 + d2y(a,n,n)
  * ( 1/4*c^-3*norm )
 
 + d3y(u,n,n,n)
  * ( - 1/6*c^-2 ) + 0;

id aDa = a.a;
id norm = snorm;
id norm^p? = snorm^p;
.sort

hide tau1o,tau2o,tau3o;

G diff1 = TAU1 - tau1o;
G diff2 = TAU2 - tau2o;
G diff3 = TAU3 - tau3o;
sum mu,nu,Naa,Nab;
b snorm;
print;
.end
