*   Title:  SMALL CHARGED SPHERE:
*           Lorentz force, retarded/advanced time interval
*    File:  dtau.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  November 7, 1987 (Schoonschip)
*           July 2, 2012     (Form)
* Revised:  July 2-9,23,28, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  none, this is first
*  Output:  TAU1, TAU2, TAU3, in dtau.sav

#if 0

The retarded, respectively, advanced proper time interval δτ
(negative, respectively, positive) is computed as a function of
the proper three-position α of a charge element experiencing the
field, and the proper source three-position β of a source charge
element, using the four-vector light-cone displacement R from
the retarded or advanced source source element to the element
experiencing the field.

  α        field point proper three-position
  β        source point proper three-position
  τ        field point proper time
  τ'       source point proper time
  n        (β-α)/|β-α|
  ε        |β-α|, assumed small
  δτ       τ'-τ, small of leading order ε
  y(τ,α)   field point four-position
  y(τ',β)  source point four-position
  R        y(τ,α)-y(τ',β), four-displacement from source to
           field
  u(τ,α)   field point four-velocity ∂y/∂τ
  a(τ,α)   field point four-acceleration ∂u/∂τ
  j(τ,α)   field point four-jerk ∂a/∂τ
  ηᵢ(τ,α)  field point distortion four-vector, ∇ᵢy-uu⋅∇ᵢy/c²
  ηᵢⱼ(τ,α) field point strain tensor, -ηᵢ⋅ηⱼ
  ||n||²   squared strain norm of n, nᵢ ηᵢⱼ nⱼ ≥ 0 
  ρ(α)     proper charge density
  Q        total charge, ∫ρ(α)d³α
  c        speed of light

The support of the proper charge distribution is small, and
limits the size of ε.

The retarded and advanced proper times are the two solutions of
the light-cone condition R⋅R = 0 for τ'.

The expansion of the source point in terms of the field point is

  y(τ',β) = y(τ,β) + δτ u(τ,β) + ½ δτ² a(τ,β) + ⅙ δτ³ j(τ,β) + ...
  
     = y(τ,α) + ε n⋅∇y(τ,α) + ½ ε² nn:∇∇y(τ,α) + ⅙ ε³ nnn⫶∇∇∇y
 
     + δτ u(τ,α) + δτ ε n⋅∇u(τ,α) + ½ δτ ε² nn:∇∇u

     + ½ δτ² a(τ,α) + ½ δτ² ε n⋅∇a(τ,α)

     + ⅙ δτ³ j(τ,α) + ...

  δτ = τ₁ ε + τ₂ ε² + τ₃ ε³ + ...

The idea is to get the power series solution for δτ in terms of
ε through order ε³ by solving R⋅R = 0 for the δτ coefficients
τ₁, τ₂, and τ₃:

  R⋅R = [R⋅R]₂ ε² + [R⋅R]₃ ε³ + [R⋅R]₄ ε⁴ = 0

       => [R⋅R]₂ = 0, [R⋅R]₃ = 0, [R⋅R]₄ = 0

This works recursively because the first nonvanishing
coefficient depends only on tau1, then substituting that into
R⋅R eliminates the ε² term, and leaves the second coefficient
depending only on τ₂, etc.

Only τ₁ involves a quadratic, the solutions of which carry the
entire retarded vs. advanced dependence.  We solve for τ₁ by
hand; the program solves for τ₂ and τ₃.  The solutions are named
TAU1, TAU2, and TAU3.

#endif

*** DECLARATIONS

off statistics;

S eps,dtau;
S c,tau1,tau2,tau3;

* snorm is positive for retarded and negative for advanced
S snorm;

I mu,nu;
V y,u,a,j,n;
T d1y,d2y,d3y,d1u,d2u,d1a;

* This doesn't work:
* V R;
* This works:
CF R;

V l,m;

*** MODULES

* Express RdotR and dtau as a power series in eps through order
* eps^3.  Powers of dtau and eps in RdotR higher than 3 are
* killed by the declaration above.

L RdotR = R(mu)*R(mu);

Id R(mu?) = - d1y(mu,n)*eps - d2y(mu,n,n)*eps^2/2

                  - d3y(mu,n,n,n)*eps^3/6

            - u(mu)*dtau - d1u(mu,n)*eps*dtau

                 - d2u(mu,n,n)*eps^2*dtau/2

            - a(mu)*dtau^2/2 - d1a(mu,n)*eps*dtau^2/2

            - j(mu)*dtau^3/6;

Id d1y(mu?,n)*d1y(mu?,n) = - snorm*snorm + d1y(u,n)*d1y(u,n)/c^2;
Id u.u = c^2;
Id u.a = 0;
Id u.j = -a.a;

Id d1u(u,l?) = 0;
Id d1a(u,l?) = -d1u(a,l);
Id d2u(u,l?,m?) = -d1u(nu,l)*d1u(nu,m);

Id dtau = tau1*eps + tau2*eps^2 + tau3*eps^3;

Id eps^5 = 0;

* Avoid more than two repeated mu indices.
sum mu;
.sort

* Eliminate tau1, kill eps^2 term in RdotR and eps^0 term in
* [R.R_2].

L [R.R_2] = RdotR/eps^2;
G TAU1 = -snorm/c - d1y(u,n)/c^2;
Id tau1 = TAU1;
.sort

* Solve for tau2 and kill all eps in [R.R_3].

hide RdotR;
L [R.R_3] = RdotR/eps^3;
G TAU2 = [R.R_3]/(2*c*snorm) + tau2;
Id eps = 0;
.sort

* Eliminate tau2, which kills the eps^3 term in RdotR and makes
* [R.R_3] = 0. 

unhide RdotR;
Id tau2 = TAU2;
.sort

* Solve for tau3 and kill all eps in [R.R_4].

hide RdotR;
L [R.R_4] = RdotR/eps^4;
G TAU3 = [R.R_4]/(2*c*snorm) + tau3;
Id eps = 0;
.sort

* Eliminate tau3, which kills the eps^4 term in RdotR and makes
* [R.R_4] = 0.

unhide RdotR;
Id tau3 = TAU3;

bracket eps,snorm;
print +s;
.store

save dtau.sav;
.end
