*   Title:  SMALL CHARGE:
*           proper elastic potential energy density
*    File:  elasemPE.frm 
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  July 26, 2012
* Revised:  July 26-30, 2012
*           August 1-3, 2012
*           October 17, 2012  improved comments
*           February 4, 2013  fixed sign of dR.dF/dzet
*           March 25, 2013    renamed F as U
*           August 1, 2013    felas output
*           August 2, 2013    renamed kappa and zeta as kap and zet
*           August 3, 2013    renamed [dL.dU/dzet] and [dR.dU/dzet] as
*                             [d2U/dalp.dzet] and [d2U/dzet.dalp]
*
*   Copyright (C) 2012, 2013 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
* Purely cosmetic changes may not be reflected in the revision
* dates above.
*
*   Input:  elasforce.sav, lfsing.sav
*  Output:  elasemPE.log
*           felas in elasenPE.sav

#if 0

This program identifies a proper elastic potential energy
density for which the negative divergence of the elastic
energy-momentum tensor cancels the ℓ⁻¹ term in the
retarded/advanced Lorentz force density for a spherically
symmetric charge with small radius ℓ, leaving part of the ℓ⁻²
term, and adding an extra ℓ⁻¹ term proportion to ∂ρ₀/∂αⁱ, where
ρ₀ = ρ₀(α) is the proper charge density.

In the following, the Lorentz force density lfsing, loaded from
lfsing.sav, is missing an overall factor ρ₀/Jγ, where Jγ is an
invariant, four-dimensional Jacobian.  The model for the proper
potential energy function U is missing the same factor, which
has the effect that the model elastic force density felas lacks
the extra term with ∂ρ₀/∂αⁱ mentioned above.  These omissions
are easily corrected, and that has been done in subsequent
calculations where it matters.

The U term in felas is

  felas(mu) = - a(mu)*c^-2*U + ...

The corresponding a(mu) term in lfsing, without the overall
ρ₀/Jγ, is

  lfsing(mu) = + eps^-1*snorm^-1 * (
          - 1/2*a(mu)*c^-2
          + ...

Hence the model for U without ρ₀/Jγ is

  U = -1/2*eps^-1*snorm^-1

Note that felas = -divE.

  ζᵢⱼ = -ηᵢ⋅ηⱼ = -∂ᵢy⋅∂ⱼy + u⋅∂ᵢy u⋅∂ⱼy/c²

Substituting for U and its derivatives generates dot products
∂ᵢy⋅∂ⱼy and ηᵢ⋅ηⱼ, which can be simplified with:

  ηᵢ⋅ηⱼ = ∂ᵢy⋅∂ⱼy - u⋅∂ᵢy u⋅∂ⱼy/c² = -ζᵢⱼ

       ⇒ ∂ᵢy⋅∂ⱼy = u⋅∂ᵢy u⋅∂ⱼy/c² - ζᵢⱼ

#endif

*** DECLARATIONS

OFF statistics;

S c,U,p,L,T;
I mu,nu,la,i,i1,i2,i3,i4;
V y,u,a,n;
T d1y,d2y,d3y,d1u,d2u,d1a;
T eta;
CF [DL.dU/dzet],[DR.dU/dzet],[dL.dU/dzet],[dR.dU/dzet];
CF [DL.dU/dzet],[DR.dU/dzet],[d2U/dalp.dzet],[d2U/dzet.dalp];
T [dU/dzet],zetdot(symmetric),Deta,deta;
T dkap,dzet;
CF kap,kapdot,[d2U/dzet2];

* extra declarations from lfsing.frm
S eps,snorm;

Load elasforce.sav;
Load lfsing.sav;

*** DEBUGGING

#procedure try
.sort
B eps,snorm;
print +s;
.end
#endprocedure

*** MODULES

G felas(mu) = -divE(mu);

Id U = -1/2*eps^-1*snorm^-1;

Id [dU/dzet](i1?,i2?) = 1/4*eps^-1*snorm^-3*n(i1)*n(i2);

Id [d2U/dzet2](i1?,i2?,i3?,i4?) = -3/8*eps^-1*snorm^-5
  *n(i1)*n(i2)*n(i3)*n(i4);

Id [d2U/dalp.dzet](i1?) = [d2U/dzet.dalp](i1);
Id [d2U/dzet.dalp](i1?) = -1/4*eps^-2*snorm^-3*n(i1);

* ∂ᵢy⋅∂ⱼy = u⋅∂ᵢy u⋅∂ⱼy/c² - ζᵢⱼ
* Id d1y(mu?,n)*d1y(mu?,n) = d1y(u,n)*d1y(u,n)/c^2 - snorm^2;
.sort

L fsum = felas(mu) + lfsing(mu);
.sort

* check units
Hide felas;
Hide fsum;
L lfsingunits = lfsing(mu);
L felasunits  = felas(mu);
L fsumunits = fsum;
Id c^p? = (L/T)^p;
Id a(mu) = L/T^2;
Id u(mu) = L/T;
Id eta(mu,i?) = 1;
Id d1y(u,i?) = L/T;
Id d1u(mu?,i?) = 1/T;
Id d1y(a,i?) = L/T^2;
Id d1y(mu?,i?) = 1;
Id d2y(u,i1?,i2?) = 1/T;
Id d2y(mu?,i1?,i2?) = 1/L;
Id eps^p? = L^p;
Id snorm^p? = 1;
#if 0
* effective only if U not substituted (debugging)
Id [d2U/dalp.dzet](i?) = U/L;
Id [d2U/dzet.dalp](i?) = U/L;
Id [dU/dzet](i1?,i2?) = U;
#endif
.sort

Unhide felas;
Unhide fsum;

G flor(mu) = lfsing(mu);

Id d1y(mu?,n) = eta(mu,n) + u(mu)*d1y(u,n)/c^2;
Id u.u = c^2;
Id u.a = 0;
Id eta(u,n?)= 0;
Id d1u(u,n) = 0;

B eps,snorm;
*B eps,snorm,u,a,eta,d1y,d1u,d2y;
Print +s;

.store;
Save elasemPE.sav felas;
.end
