*   Title:  SMALL CHARGED SPHERE:  Lorentz force
*            F(mu,nu)*U(nu) leading regular order
*    File:  lfreg.frm
*  Author:  David N. Williams
* License:  Creative Commons Attribution-Share Alike
* Started:  November 7, 1987 (Schoonschip)
*           July 10, 2012     (Form)
* Revised:  July 10,28,29, 2012
* Revised:  August 5, 2012
*
* All parts of this program not in the public domain are:
*
*   Copyright (C) 1987-1990, 2012 David N. Williams
*
* This work is licensed under the Creative Commons Attribution-
* Share Alike 2.5 License.  To view a copy of this license, visit
* http://creativecommons.org/licenses/by-sa/2.5/ or send a letter
* to Creative Commons, 543 Howard Street, 5th Floor, San
* Francisco, California, 94105, USA.
*
*   Input:  TAU1, TAU2, TAU3 from dtau.sav
*           RdotA from rdota.sav
*           [1/RdotU^2], [1/RdotU^3] from denoms.sav
*  Output:  lfreg in lfreg.sav

*** DECLARATIONS

* set to "1" to kill odd n terms in lfreg
#define KILLODDN "0"

OFF statistics;

S eps;
S c,snorm;
V u,a,j,n;
T d1y,d2y,d3y,d1u,d2u,d1a;
T eta;

Load dtau.sav;
Load rdota.sav;
Load denoms.sav;

S dtau;
S [1/d^2],[1/d^3];
I mu,nu,la,l,m;
CF R,U,A;

CF [d1y*d1y];

S p;

*** DEBUGGING

#procedure try
.sort
B eps,snorm;
print +s;
.end
#endprocedure

*** MODULES

* leading nonsingular order in this section:  eps^3

L F(mu,nu) = ( R(mu)*U(nu) - R(nu)*U(mu) ) * [1/d^3] * ( c^2 - RdotA )

             + ( R(mu)*A(nu) - R(nu)*A(mu) ) * [1/d^2];


Id R(mu?) = - d1y(mu,n)*eps - d2y(mu,n,n)*eps^2/2

                - d3y(mu,n,n,n)*eps^3/6

            - u(mu)*dtau - d1u(mu,n)*eps*dtau

                - d2u(mu,n,n)*eps^2*dtau/2

            - a(mu)*dtau^2/2 - d1a(mu,n)*eps*dtau^2/2

            - j(mu)*dtau^3/6;

Id U(mu?) =   u(mu) + d1u(mu,n)*eps + d2u(mu,n,n)*eps^2/2

            + a(mu)*dtau + d1a(mu,n)*eps*dtau

            + j(mu)*dtau^2/2;

Id A(mu?) =   a(mu) + d1a(mu,n)*eps

            + j(mu)*dtau;

Id eps^4 = 0;
.sort

* Lorentz force density
G lfreg = F(mu,nu)*u(nu)/c;
Id eps^4 = 0;
Id eps^3 * dtau = 0;
Id eps^2 * dtau^2 = 0;
Id eps * dtau^3 = 0;
Id dtau^4 = 0;

Id u.u = c^2;
Id u.a = 0;
Id u.j = -a.a;

Id d1u(u,l?) = 0;
Id d1a(u,l?) = -d1u(a,l);
Id, d2u(u,l?,m?) = -d1u(la,l)*d1u(la,m);
Sum la;

Id dtau = TAU1*eps + TAU2*eps^2 + TAU3*eps^3;
Id eps^4 = 0;
.sort

Id [1/d^2] = [1/RdotU^2];
Id [1/d^3] = [1/RdotU^3];
.sort

* kill superfluous order from RdotA
Id eps = 0;

* kill singular orders
Id eps^-1 = 0;

Id d1y(mu,n) = eta(mu,n) + d1y(u,n)*u(mu)*c^-2;
.sort

hide F;

* kill odd powers of n
#if `KILLODDN'
if ( count(n,1) == 7 ) discard;
if ( count(n,1) == 5 ) discard;
if ( count(n,1) == 3 ) discard;
if ( count(n,1) == 1 ) discard;
#endif

Id d1y(mu?,n)*d1y(nu?,n) = [d1y*d1y](mu,nu);
.sort

* kill symmetric times antisymmetric

symmetrize [d1y*d1y];
Id [d1y*d1y](mu?,nu?) = d1y(mu,n)*d1y(nu,n);

.sort

unhide F;
b eps,snorm;
print +s;
.store

save lfreg.sav;
.end
